summaryrefslogtreecommitdiffstats
path: root/kmymoney2/reports/reportaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/reports/reportaccount.h')
-rw-r--r--kmymoney2/reports/reportaccount.h54
1 files changed, 27 insertions, 27 deletions
diff --git a/kmymoney2/reports/reportaccount.h b/kmymoney2/reports/reportaccount.h
index e07f9b1..91db6a2 100644
--- a/kmymoney2/reports/reportaccount.h
+++ b/kmymoney2/reports/reportaccount.h
@@ -22,7 +22,7 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qstringlist.h>
+#include <tqstringlist.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -54,20 +54,20 @@ namespace reports {
class ReportAccount: public MyMoneyAccount
{
private:
- QStringList m_nameHierarchy;
+ TQStringList m_nameHierarchy;
public:
/**
* Default constructor
*
- * Needed to allow this object to be stored in a QMap.
+ * Needed to allow this object to be stored in a TQMap.
*/
ReportAccount( void );
/**
* Copy constructor
*
- * Needed to allow this object to be stored in a QMap.
+ * Needed to allow this object to be stored in a TQMap.
*/
ReportAccount( const ReportAccount& );
@@ -76,7 +76,7 @@ public:
*
* @param accountid Account which this account descriptor should be based off of
*/
- ReportAccount( const QString& accountid );
+ ReportAccount( const TQString& accountid );
/**
* Regular constructor
@@ -110,7 +110,7 @@ public:
* @param date The date in question
* @return MyMoneyMoney The value of the account's currency on that date
*/
- MyMoneyMoney deepCurrencyPrice( const QDate& date ) const;
+ MyMoneyMoney deepCurrencyPrice( const TQDate& date ) const;
/**
* Returns the price of this account's deep currency on the indicated date,
@@ -119,7 +119,7 @@ public:
* @param date The date in question
* @return MyMoneyMoney The value of the account's currency on that date
*/
- MyMoneyMoney baseCurrencyPrice( const QDate& date ) const;
+ MyMoneyMoney baseCurrencyPrice( const TQDate& date ) const;
/**
* Returns the price of this account's deep currency on the indicated date,
@@ -129,7 +129,7 @@ public:
* @param date The date in question
* @return MyMoneyMoney The value of the account's currency on that date
*/
- MyMoneyMoney foreignCurrencyPrice( const QString foreignCurrency, const QDate& date ) const;
+ MyMoneyMoney foreignCurrencyPrice( const TQString foreignCurrency, const TQDate& date ) const;
/**
* Fetch the trading symbol of this account's deep currency
@@ -151,9 +151,9 @@ public:
* method only returns the last name in the list, which is the engine name]
* of this account.
*
* @return QString The account's name
*/
- QString name( void ) const;
+ TQString name( void ) const;
/**
* The entire hierarchy of this account descriptor
@@ -161,52 +161,52 @@ public:
* to always look pretty, while fullName() is. So if the user is ever
* going to see the results, use fullName().
*
* @return QString The account's full hierarchy
*/
- QString fullName( void ) const;
+ TQString fullName( void ) const;
/**
* The entire hierarchy of this account descriptor, suitable for displaying
* in debugging output
*
* @return QString The account's full hierarchy (suitable for debugging)
*/
- QString debugName( void ) const;
+ TQString debugName( void ) const;
/**
* Whether this account is a 'top level' parent account. This means that
* it's parent is an account class, like asset, liability, expense or income
*
* @return bool True if this account is a top level parent account
*/
/*inline*/ bool isTopLevel( void ) const;
/**
* Returns the name of the top level parent account
*
* (See isTopLevel for a definition of 'top level parent')
*
* @return QString The name of the top level parent account
*/
- /*inline*/ QString topParentName( void ) const;
+ /*inline*/ TQString topParentName( void ) const;
/**
* Returns a report account containing the top parent account
*
* @return ReportAccount The account of the top parent
*/
ReportAccount topParent( void ) const;
/**
* Returns a report account containing the immediate parent account
*
* @return ReportAccount The account of the immediate parent
*/
- ReportAccount parent( void ) const;
+ ReportAccount tqparent( void ) const;
/**
* Returns the number of accounts in this account's hierarchy. If this is a
* Top Category, it returns 1. If it's parent is a Top Category, returns 2,
* etc.
*
* @return unsigned Hierarchy depth
@@ -151,9 +151,9 @@ public:
* of this account.
*
- * @return QString The account's name
+ * @return TQString The account's name
*/
@@ -161,52 +161,52 @@ public:
* going to see the results, use fullName().
*
- * @return QString The account's full hierarchy
+ * @return TQString The account's full hierarchy
*/
@@ -161,52 +161,52 @@ public:
* in debugging output
*
- * @return QString The account's full hierarchy (suitable for debugging)
+ * @return TQString The account's full hierarchy (suitable for debugging)
*/
@@ -161,52 +161,52 @@ public:
/**
- * Whether this account is a 'top level' parent account. This means that
- * it's parent is an account class, like asset, liability, expense or income
+ * Whether this account is a 'top level' tqparent account. This means that
+ * it's tqparent is an account class, like asset, liability, expense or income
*
@@ -161,52 +161,52 @@ public:
*
- * @return bool True if this account is a top level parent account
+ * @return bool True if this account is a top level tqparent account
*/
/*inline*/ bool isTopLevel( void ) const;
@@ -161,52 +161,52 @@ public:
/*inline*/ bool isTopLevel( void ) const;
/**
- * Returns the name of the top level parent account
+ * Returns the name of the top level tqparent account
*
@@ -161,52 +161,52 @@ public:
*
- * (See isTopLevel for a definition of 'top level parent')
+ * (See isTopLevel for a definition of 'top level tqparent')
*
@@ -161,52 +161,52 @@ public:
*
- * @return QString The name of the top level parent account
+ * @return TQString The name of the top level tqparent account
*/
@@ -161,52 +161,52 @@ public:
/**
- * Returns a report account containing the top parent account
+ * Returns a report account containing the top tqparent account
*
@@ -161,52 +161,52 @@ public:
*
- * @return ReportAccount The account of the top parent
+ * @return ReportAccount The account of the top tqparent
*/
ReportAccount topParent( void ) const;
@@ -161,52 +161,52 @@ public:
ReportAccount topParent( void ) const;
/**
- * Returns a report account containing the immediate parent account
+ * Returns a report account containing the immediate tqparent account
*
@@ -161,52 +161,52 @@ public:
*
- * @return ReportAccount The account of the immediate parent
+ * @return ReportAccount The account of the immediate tqparent
*/
@@ -161,52 +161,52 @@ public:
/**
* Returns the number of accounts in this account's hierarchy. If this is a
- * Top Category, it returns 1. If it's parent is a Top Category, returns 2,
+ * Top Category, it returns 1. If it's tqparent is a Top Category, returns 2,
* etc.
*